%CODIFICADOR DE LA EXCITACIÓN RESIDUAL.
%function [Mc,xmaxc,xmc,ep]=rpec(e)
%Entradas:
%e:excitación residual.
%Salidas:
%Mc:posición RPE codificada.
%xmaxc:valor máximo RPE codificado.
%xmc:subsecuencia RPE codificada.
%ep:excitación residual decodificada.
function [Mc,xmaxc,xmc,ep]=rpec(e)
x=ponder(e); %aplicamos el filtro de ponderación.
[Mc,xm]=rpesel(x); %calculamos la subsecuencia seleccionada.
[xmc,xmaxc]=apcmcod(xm); %codificamos los términos RPE.
xmp=apcmdec(xmc,xmaxc); %decodificamos los términos RPE codificados.
ep=rpepos(Mc,xmp); %decodificamos la excitación residual.